#ifndef QBTKEYBOARDS_H
#define QBTKEYBOARDS_H

#include <QWidget>
#include <QMap>
#include <QString>
#include <QVariant>
#include <QDBusReply>

class QBTKeyboards : public QMap< QString, QMap<QString,QVariant> >
{
public:
    QBTKeyboards(QWidget *parent = 0);
    //void reconnect(bool connectedOnly=true);
    QWidget * parent(){return m_parent;};
    //bool reconnectConnectedOnly(){return m_reconnectConnectedOnly;};

protected:
    virtual bool enumerateHIDDeviceProperties(bool (*enumFunc)(QBTKeyboards* _this,const QDBusReply< QMap<QString,QVariant> > & properties));

protected:
    QWidget *m_parent;
    bool m_reconnectConnectedOnly;
};

#endif // QBTKEYBOARDS_H
